<?php

namespace Drupal\webt\Controller;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Controller\ControllerBase;
use Drupal\webt\AssetManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller that generates content for About section.
 */
class AboutTabController extends ControllerBase {

  /**
   * Asset manager.
   *
   * @var Drupal\webt\AssetManager
   */
  private $assetManager;

  /**
   * Constructor.
   *
   * @param Drupal\webt\AssetManager $asset_manager
   *   Asset manager.
   */
  public function __construct(AssetManager $asset_manager) {
    $this->assetManager = $asset_manager;
  }

  /**
   * Generate markup.
   *
   * @return array
   *   About tab content
   */
  public function content() {
    $about_heading = $this->t('About WEB-T module');
    $about_content = $this->t('WEB-T is a module that allows you to translate your Drupal website content using machine translation. It comes with a default translation provider, eTranslation, but can be configured to use custom providers.');

    $configure_content = new FormattableMarkup(
      $this->t("See how to <a target='_blank' href='@link'>configure and use this plugin</a>."),
      [
        '@link' => 'https://website-translation.language-tools.ec.europa.eu/solutions/drupal_en',
      ]
    );

    $more_info_heading = $this->t('More information');
    $more_info_content = $this->t('WEB-T is a part of European Multilingual Web (EMW) project by EC');
    $learn_more        = $this->t('Learn more');
    $learn_more_link   = 'https://website-translation.language-tools.ec.europa.eu/web-t-connecting-languages-0_en';

    $ec_logotype_url   = $this->assetManager->getAssetUrl('images/ec_logotype.svg');
    $webt_logotype_url = $this->assetManager->getAssetUrl('images/webt_logotype.svg');

    $text = "
			<h5>$about_heading</h5>
			<p>
				$about_content
			</p>
			<p>
				$configure_content
			</p>
			<h5>$more_info_heading</h5>
			<p>
				$more_info_content (<a target='_blank' href='$learn_more_link'>$learn_more</a>).
			</p>
			<p>
				<img alt='EC logotype' class='logotypes' src='$ec_logotype_url' />
				<img alt='WEBT logotype' class='logotypes' src='$webt_logotype_url' id='webt_logtype' />
			</p>
			";

    return [
      '#markup'   => $text,
      '#attached' => [
        'library' => [
          'webt/about_tab.style',
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('webt.asset_manager')
    );
  }

}
